/*
REPLICATION FILE FOR:

Kai Gehring and Valentin Lang:
Stigma or Cushion? IMF Programs and Sovereign Creditworthiness,
 Journal of Development Economics 146 (2020).
*/
 
 
version 14
drop _all
clear matrix
clear mata
set mat 5000
set more off,perm

********************************************************************************
*SET DIRECTORIES
*Kai work
local DIR ="C:\Users\gehring\Documents\Dropbox\IMF Rating\Stata"
cap  cd "`DIR'"

*Kai Home
local DIR ="C:\Users\kai_g\Dropbox\IMF Rating\Stata"
cap  cd "`DIR'"

*Valentin
global DIR = "/Users/lang/Dropbox/IMF_Rating/Stata"
cap cd "$DIR"
********************************************************************************


***********************************************************************************************************
******************** Final Merges, Adjustments, and add bond spreads **************************************
***********************************************************************************************************

use "processed/IMF_Rating_complete_old", replace

save "processed/temp1.dta", replace

use "IMF_Cambridge.dta", clear
ren wdicode code
replace code = "ROM" if code == "ROU"
replace code = "TMP" if code == "TLS"
replace code = "ADO" if code == "AND"
replace code = "ZAR" if code == "COD"
save "processed/IMF_Cambridge.dta", replace
use "processed/temp1.dta", clear
merge 1:1 code year using "processed/IMF_Cambridge.dta"
drop if _merge == 2 // only 3 obs


save "processed/temp2.dta", replace
use "KOFRAW2.dta", clear
ren wdicode_j code
replace code = "ROM" if code == "ROU"
replace code = "TMP" if code == "TLS"
replace code = "ADO" if code == "AND"
replace code = "ZAR" if code == "COD"
save "processed/KOFRAW.dta", replace
use "processed/temp2.dta", clear
drop _merge
merge 1:1 code year using "processed/KOFRAW.dta"
drop if _merge == 2 // only unncesseary obs

save "processed/temp3.dta" , replace

*R&R: add debt service

wbopendata, indicator(	DT.TDS.DECT.EX.ZS; DT.SRV.POST.ZS; DT.TDS.DECT.GD.ZS; DT.TDS.DPPG.CD; DT.TDS.DPPG.GN.ZS; GB.TDS.FRGN.CN; ///
						DT.DOD.PVLX.CD; DT.DOD.PVLX.EX.ZS; DT.DOD.PVLX.GN.ZS; DT.DOD.PVLX.ND.ZS; ///
						DT.TDA.DECT.CD; GB.TDS.ABRD.CN; DT.TXR.DPPG.CD; DT.DFR.DPPG.CD;   ///
						DT.DOD.DECT.CD) ///
						long clear nometadata year(1973:2015) 


*debt service

ren dt_tds_dect_ex_zs  ds2ex       
lab var ds2ex "DT.TDS.DECT.EX.ZS - Total debt service (% of exports of goods, services and income)"
ren dt_srv_post_zs        ds2expost   
lab var ds2expost "DT.SRV.POST.ZS - Debt service to export ratio, ex-post (%)"
ren dt_tds_dect_gd_zs ds2gdp
lab var ds2gdp "DT.TDS.DECT.GD.ZS - Total debt service (% of GDP)"
ren dt_tds_dppg_cd    ds          
lab var ds "DT.TDS.DPPG.CD - Debt service on external debt, public and publicly  guaranteed (PPG) (TDS, current US$)"
ren dt_tds_dppg_gn_zs	            ds2gni
lab var ds2gni "DT.TDS.DPPG.GN.ZS - Public and publicly guaranteed debt service (%  of GNI)"
ren gb_tds_frgn_cn    dscentral           
lab var dscentral "GB.TDS.FRGN.CN - Central government debt service, external (current LCU)"
	
*present value
ren dt_dod_pvlx_cd pv
lab var pv "DT.DOD.PVLX.CD - Present value of external debt (current US$)"
ren dt_dod_pvlx_ex_zs    pv2ex
lab var pv2ex "DT.DOD.PVLX.EX.ZS - Present value of external debt (% of exports of goods, services and income)"
ren dt_dod_pvlx_gn_zs     pv2gni       
lab var pv2gni "DT.DOD.PVLX.GN.ZS - Present value of external debt (% of GNI)"
ren dt_dod_pvlx_nd_zs pv2nominal
lab var pv2nominal "DT.DOD.PVLX.ND.ZS - Present value to nominal value of debt (%)"
		

*restructuring
ren dt_tda_dect_cd adjustds
lab var adjustds "DT.TDA.DECT.CD - Adjustments to scheduled debt service (current US$)"
ren gb_tds_abrd_cn adjustdsfor
lab var adjustdsfor "GB.TDS.ABRD.CN - Adjustments to foreign scheduled debt service (current LCU)"
ren dt_txr_dppg_cd debtreschedule
lab var debtreschedule "DT.TXR.DPPG.CD - Total amount of debt rescheduled (current US$)"
ren dt_dfr_dppg_cd debtreduction
lab var debtreduction "DT.DFR.DPPG.CD - Debt forgiveness or reduction (current US$)"

*external debt
ren dt_dod_dect_cd externaldebtstock
lab var externaldebtstock "DT.DOD.DECT.CD - External debt stocks, total (DOD, current US$)"

drop  region regionname
rename countrycode code
mdesc * // almost all missings for:
drop ds2expost dscentral pv pv2ex pv2gni pv2nominal adjustdsfor
mdesc * // candidates are: ds2gni ds2ex debtreschedule debtreduction
replace code = "ROM" if code == "ROU"
replace code = "TMP" if code == "TLS"
replace code = "ADO" if code == "AND"
replace code = "ZAR" if code == "COD"
save "processed/debt_WDI.dta", replace

use "processed/temp3.dta", clear
drop _merge
merge 1:1 code year using "processed/debt_WDI.dta"
tab country_name if _merge == 1
drop if _merge == 2 // only unncesseary obs

gen debtreschedule2gdp = debtreschedule / gdp_curr
gen debtreduction2gdp = debtreduction / gdp_curr
gen externaldebtstock2gdp = externaldebtstock / gdp_curr

bys code:egen ExsCount=count(externaldebtstock2gdp) 
replace externaldebtstock2gdp = 0 if externaldebtstock2gdp==. & ExsCount==0 & gdp_pc_const>=2996 & gdp_pc_const!=.  // 18.3.2020 VL: changed gdppc to gdp_pc_const in the line above

save "processed/temp4.dta", replace

import excel "haircuts.xlsx", clear firstrow sheet("2014 Version (new)") cellrange(C12:U200)
drop if Case == .
rename Code code
gen year = year(Date)
foreach var of varlist DebtRestructuredmUS PreferredHaircutHSZ UnderlyingDiscount MarketHaircutHM FaceValueReductionin BondExchange ReductinFaceValue BuyBackDeal BradyDeal DonorFunded AllFallenDue AffectsPRD NewMoneyIncl ShortTermDebtIncl DataQualityIndex {
	destring `var', replace force
	ren `var' `var'_trebesch
}
drop Case
order CountryCase code year
replace code = "ROM" if code == "ROU"
replace code = "TMP" if code == "TLS"
replace code = "ADO" if code == "AND"
replace code = "ZAR" if code == "COD"

duplicates list code year
save "processed/haircuts.dta", replace

keep CountryCase code year DebtRestructuredmUS_trebesch
collapse (sum) DebtRestructuredmUS_trebesch, by(code year)
ren DebtRestructuredmUS_trebesch debtrestructured_trebesch
save "processed/haircuts_onlydebt.dta", replace

use "processed/temp4.dta", clear
drop _merge
merge 1:1  code year using "processed/haircuts_onlydebt.dta"

replace debtrestructured_trebesch = 0 if debtrestructured_trebesch == .
gen restructured2gdp = (debtrestructured_trebesch*1000000) / gdp_curr

gen restructured_dummy = 1 if restructured2gdp > 0 & restructured2gdp !=.
replace restructured_dummy = 0 if restructured_dummy != 1



rename code wdicode
drop _merge 
replace wdicode = "ROU" if wdicode == "ROM"
replace wdicode = "COD" if wdicode == "ZAR"

merge 1:1 wdicode year using "processed/crises_LV2018.dta"
drop if _merge == 2
drop _merge

rename wdicode code


*code global growth and global FDI
cap drop hic2013 hic g1_totalgdphic totalgdphic
gen hic2013 = 0
replace hic2013 = 1 if gdp_pc_const > 12745 & year == 2013 & gdp_pc_const != . // info from world bank classification
bys code: egen hic = total(hic2013)
bys hic year: egen totalgdphic = total(gdp_const)
twoway (line totalgdphic year if hic == 1)  (line totalgdphic year if hic == 0)
xtset countryID year
sort countryID year
gen g1_totalgdphic = ((totalgdphic/l.totalgdphic) - 1) * 100
sort year
twoway (line g1_totalgdphic year if hic == 1)  (line g1_totalgdphic year if hic == 0) // 1989 is an error
replace g1_totalgdphic = . if year == 1989 & hic == 0
replace g1_totalgdphic = . if year > 2013 & hic == 0

gen KOF_fdiin_st_gdp_hic = KOFRAW_fdi_st_in if hic2013 == 0
bys year: egen fdiin2gdp_hic = wtmean(KOF_fdiin_st_gdp_hic) , weight(gdp_const)
sort countryID year
gen d1_fdiin2gdp_hic = fdiin2gdp_hic - l.fdiin2gdp_hic



replace bankexp_fi = bankexp_fi / 1000


drop yeardummies*
drop countrydummies*

tab year, gen(yeardummies)
tab code, gen(countrydummies)





save "processed/IMFRATING2.dta", replace

*save  "processed/IMF_rating_final1", replace












*******************************************************************************************************************
*****************************new negotiation data**************************************************************
***************************************************************************************************************
use "processed/IMF_rating_monthly.dta" ,clear
keep if IMFapproval==1
keep if rat1sp_monthly !=.
export excel negotiations, replace // Export data, then add negotiations based on background research

**Feed in data on negotiations
import excel "negotiation_final.xls", sheet("Sheet1") firstrow clear
keep country_name-not_IMFstart 
keep if not_IMFstart==0  //Only keep new programs, not prolongations
destring year month Neg_year Neg_month Uncertainty, replace force float

**Create variable for those where no info about negotiations available
gen no_nego_info=0
replace no_nego_info=1 if Neg_month==.
label var no_nego_info "No information about negotiation begin available"
gen time_neg_to_start=0

gen neg_delay__year=year-Neg_year
gen neg_delay__month=month-Neg_month
replace time_neg_to_start=neg_delay__month if neg_delay__year==0
replace time_neg_to_start=neg_delay__month+12 if neg_delay__year==1
replace time_neg_to_start=neg_delay__month+24 if neg_delay__year==2
replace time_neg_to_start=neg_delay__month+36 if neg_delay__year==3
*****Cases where we have no info, to be coded for robustness test later
replace Neg_year=year if no_nego_info==1
replace Neg_month=month if no_nego_info==1

ren Uncertainty uncertainty
replace uncertainty = 0 if no_nego_info==1

label var time_neg_to_start "Months between begin negotiations and IMF start"
drop programname year country_name month neg_delay__year neg_delay__month not_IMFstart uncertainty

gen negotiation_begin=1 // Will be set to zero for other cases when merged
label var negotiation_begin "Month and year where negotiations for program begin"
rename Neg_year year
ren Neg_month month


destring year month , replace force float
drop if year==. //For those cases we did not find any information about the beginning of negotiations
drop if country_code=="" //empty observation
//label var not_IMFstart "IMF program approved, but not new start"

save "processed/IMF_negotiations.dta" ,replace











********************************
*MONTHLY DATA*******************
********************************

use "processed/finalRatings_wide.dta", clear
rename code1 country_code
*merge doesnt work because not unique in code year month
duplicates list country_code year month // 2013 and 2015 month 5,6,7
duplicates tag country_code year month, gen (dup) // 2013 and 2015 month 5,6,7
*br if dup == 1
*dont use collapse because missings turn into zeros, collapse by hand:
egen codeyearmonthgroup = group(country_code year month)
foreach var of varlist rat1ci rat1Eci rat1dagong rat1Edagong rat1dbrs rat1Edbrs rat1feri rat1Eferi rat1fitch rat1Efitch rat1jcr rat1Ejcr rat1moody rat1Emoody rat1ri rat1Eri rat1sp rat1Esp {
bysort codeyearmonthgroup: egen `var'_monthly = total(`var'), missing
}
duplicates drop country_code year month, force
drop rat1ci rat1Eci rat1dagong rat1Edagong rat1dbrs rat1Edbrs rat1feri rat1Eferi rat1fitch rat1Efitch rat1jcr rat1Ejcr rat1moody rat1Emoody rat1ri rat1Eri rat1sp rat1Esp
drop dup codeyearmonthgroup

save "processed/Ratings_monthly_temp.dta", replace



use "IMFprograms_archiveandcurrent_monthly_Sep16.dta", clear

merge 1:1 country_code year month using "processed/Ratings_monthly_temp.dta",  

merge 1:1 country_code year month using "processed/IMF_negotiations.dta", keep(1 3) nogen

merge 1:1 country_code year month using "processed/Bondspread_monthly_all",keep(1 3) nogen



/*
    not matched                        38,481
        from master                    11,139  (_merge==1)
        from using                     27,342  (_merge==2)
		
    matched                            25,461  (_merge==3)
*/

*keep _merge (may be useful later)

drop countryID yearmonth monthcount
gen yearmonth = (year*100) + month
order country_name country_code year month yearmonth IMFapproval IMFend IMFprogram edate  rat*
sort country_code year month



replace negotiation_begin=0 if negotiation_begin==.
replace negotiation_begin=0 if no_nego_info == 1  //For those cases no information about negotiation

sort country_code year month
egen countryID = group(country_code)
egen countryyearID = group(country_code year)
sort yearmonth
sort countryID year month
sort yearmonth
egen monthcount = group(yearmonth)
tostring _merge, replace force
replace _merge = "IMF data only" if _merge == "1"
replace _merge = "Rating data only" if _merge == "2"
replace _merge = "IMF and Rating Data" if _merge == "3"
rename _merge datasources

drop if year < 1990

replace IMFprogram = 0 if IMFprogram == .
bys country_code: egen totalIMFmonths = total(IMFprogram)

/* Greece graph
sort yearmonth
egen monthcount = group(yearmonth)
list monthcount if yearmonth == 201005
label var monthcount "months since 1990"
twoway line rat1Esp_monthly monthcount if country_name == "greece", xline(245)
*/

/*
*damit nicht ganz so viele Variablen entstehen beim FE erstellen:
drop if IMFprogram == .
drop if rat1ci_monthly == . & rat1Eci_monthly == . & rat1dagong_monthly == . & 	rat1Edagong_monthly == . & 	rat1dbrs_monthly  == . & ///
		rat1Edbrs_monthly == . & rat1feri_monthly == . & rat1Eferi_monthly == . & rat1fitch_monthly == . & 	rat1Efitch_monthly  == . & 	rat1jcr_monthly == . & ///
		rat1Ejcr_monthly  == . & rat1moody_monthly  == . & rat1Emoody_monthly  == . & rat1ri_monthly  == . & rat1Eri_monthly  == . & rat1sp_monthly  == . & rat1Esp_monthly == . 
*/

xtset countryID monthcount
sort countryID monthcount
gen IMFstart = 0
replace IMFstart = 1 if IMFprogram == 1 & l.IMFprogram == 0 
tab IMFstart IMFapproval // 353 starts, 100 approvals without start (updated programs), 0 starts without approval

cap drop IMFend
gen IMFend = 0
replace IMFend = 1 if IMFprogram == 0 & l.IMFprogram == 1 // 322 ends

*test:
gen IMFstart2 = 0
replace IMFstart2 = 1 if IMFapproval ==  1 & l.IMFprogram == 0
tab IMFstart IMFstart2
drop IMFstart2 //test OK

bys country_code: egen cmean_rat1Esp = mean(rat1Esp_monthly)
gen devmean_rat1Esp = rat1Esp_monthly - cmean_rat1Esp
******************
gen monthsafternegotiation_begin = 0
xtset countryID monthcount
sort countryID monthcount
quietly{
forvalues i = 1(1)36 {
replace monthsafternegotiation_begin = `i' if l`i'.negotiation_begin == 1
}
forvalues i = 1(1)36 {
replace monthsafternegotiation_begin = -`i' if f`i'.negotiation_begin == 1
}
}
replace monthsafternegotiation_begin=. if monthsafternegotiation_begin==0 & negotiation_begin!=1

*******Month after cases where negotiation data not available
gen no_nego_info_period = .
xtset countryID monthcount
sort countryID monthcount
quietly{
forvalues i = 1(1)36 {
replace no_nego_info_period = `i' if l`i'.no_nego_info == 1
}
forvalues i = 1(1)36 {
replace no_nego_info_period = -`i' if f`i'.no_nego_info == 1
}
}
replace no_nego_info_period=. if no_nego_info_period==0 & no_nego_info!=1
replace no_nego_info=1 if no_nego_info_period!=. 
replace no_nego_info=. if negotiation_begin == 1



*Fill up time between negotiation and IMFstart, for up to 12 months around Negotiation
sort country_code year month

bysort country_code : carryforward time_neg_to_start if monthsafternegotiation_begin !=0, replace

gsort country_code year - month
bysort country_code : carryforward time_neg_to_start if monthsafternegotiation_begin !=0, replace
gsort country_code year + month

bysort country_code : carryforward time_neg_to_start if monthsafternegotiation_begin !=0, replace
gsort country_code -year - month
bysort country_code : carryforward time_neg_to_start if monthsafternegotiation_begin !=0, replace

sort country_code year  month
************************
gen monthsafterIMFstart = 0
xtset countryID monthcount
sort countryID monthcount
quietly{
forvalues i = 1(1)36 {
replace monthsafterIMFstart = `i' if l`i'.IMFstart == 1
}
forvalues i = 1(1)36 {
replace monthsafterIMFstart = -`i' if f`i'.IMFstart == 1
}
}
replace monthsafterIMFstart=. if monthsafterIMFstart==0 & IMFstart!=1
************Negotiation but no program yet
gen neg_but_no_agreement=0
replace neg_but_no_agreement=1 if monthsafternegotiation_begin>=0 & monthsafterIMFstart <0 & monthsafterIMFstart !=. & monthsafternegotiation_begin!=.
*Agreement and negotiation begin more than 11 months ago
gen agree_no_new_neg=0
replace agree_no_new_neg=1 if IMFstart==1 & monthsafternegotiation_begin>11 & monthsafterIMFstart !=. & monthsafternegotiation_begin!=.



*code only first IMFprogram start
xtset countryID monthcount
sort countryID monthcount
bys countryID: gen sumIMFstart = sum(IMFstart)
gen firstIMFstart = IMFstart
replace firstIMFstart = 0 if sumIMFstart > 1
tab firstIMFstart // 122 first starts

gen monthsafterfirstIMFstart = 0
xtset countryID monthcount
sort countryID monthcount
quietly{
forvalues i = 1(1)324 {
replace monthsafterfirstIMFstart = `i' if l`i'.firstIMFstart == 1
}
forvalues i = 1(1)324 {
replace monthsafterfirstIMFstart = -`i' if f`i'.firstIMFstart == 1
}
}
bysort country_code year: egen totalIMFstarts_cy = total(IMFstart)

save "processed/IMFRATINGMONTHLY2.dta", replace





